@@ -1,12 +1,14 @@
+# frozen_string_literal: true
+
 require 'active_model'
 require 'active_support/core_ext/hash/keys'
-require 'active_support/core_ext/module/attribute_accessors.rb'
+require 'active_support/core_ext/module/attribute_accessors'
 require 'state_machines'
 require 'state_machines/integrations/base'
 require 'state_machines/integrations/active_model/version'
 
 module StateMachines
-  module Integrations #:nodoc:
+  module Integrations # :nodoc:
     # Adds support for integrating state machines with ActiveModel classes.
     #
     # == Examples
@@ -25,9 +27,9 @@ module StateMachines
     #     attr_accessor :state
     #     define_attribute_methods [:state]
     #
-    #     state_machine :initial => :parked do
+    #     state_machine initial: :parked do
     #       event :ignite do
-    #         transition :parked => :idling
+    #         transition parked: :idling
     #       end
     #     end
     #   end
@@ -45,7 +47,7 @@ module StateMachines
     #     include ActiveModel::Validations
     #     attr_accessor :state
     #
-    #     state_machine :action => :save do
+    #     state_machine action: :save do
     #       ...
     #     end
     #
@@ -83,7 +85,7 @@ module StateMachines
     #     state_machine do
     #       ...
     #       state :first_gear, :second_gear do
-    #         validate {|vehicle| vehicle.speed_is_legal}
+    #         validate { |vehicle| vehicle.speed_is_legal }
     #       end
     #     end
     #   end
@@ -115,38 +117,44 @@ module StateMachines
     # Beware that public event attributes mean that events can be fired
     # whenever mass-assignment is being used.  If you want to prevent malicious
     # users from tampering with events through URLs / forms, the attribute
-    # should be protected like so:
+    # should be protected using Strong Parameters in your controllers:
     #
     #   class Vehicle
-    #     include ActiveModel::MassAssignmentSecurity
     #     attr_accessor :state
     #
-    #     attr_protected :state_event
-    #     # attr_accessible ... # Alternative technique
-    #
     #     state_machine do
     #       ...
     #     end
     #   end
     #
+    #   # In your controller
+    #   def vehicle_params
+    #     params.require(:vehicle).permit(:attribute1, :attribute2) # Exclude :state_event
+    #   end
+    #
     # If you want to only have *some* events be able to fire via mass-assignment,
-    # you can build two state machines (one public and one protected) like so:
+    # you can build two state machines (one private and one public) like so:
     #
     #   class Vehicle
     #     attr_accessor :state
     #
-    #     attr_protected :state_event # Prevent access to events in the first machine
-    #
     #     state_machine do
     #       # Define private events here
     #     end
     #
     #     # Public machine targets the same state as the private machine
-    #     state_machine :public_state, :attribute => :state do
+    #     state_machine :public_state, attribute: :state do
     #       # Define public events here
     #     end
     #   end
     #
+    #   # In your controller
+    #   def vehicle_params
+    #     # Only permit events from the public state machine
+    #     params.require(:vehicle).permit(:attribute1, :attribute2, :public_state_event)
+    #     # The private state_event is not permitted
+    #   end
+    #
     # == Callbacks
     #
     # All before/after transition callbacks defined for ActiveModel models
@@ -159,7 +167,7 @@ module StateMachines
     #     include ActiveModel::Validations
     #     attr_accessor :state
     #
-    #     state_machine :initial => :parked do
+    #     state_machine initial: :parked do
     #       before_transition any => :idling do |vehicle|
     #         vehicle.put_on_seatbelt
     #       end
@@ -169,7 +177,7 @@ module StateMachines
     #       end
     #
     #       event :ignite do
-    #         transition :parked => :idling
+    #         transition parked: :idling
     #       end
     #     end
     #
@@ -181,64 +189,6 @@ module StateMachines
     # Note, also, that the transition can be accessed by simply defining
     # additional arguments in the callback block.
     #
-    # == Observers
-    #
-    # In order to hook in observer support for your application, the
-    # ActiveModel::Observing feature must be included.  This can be added by including the
-    # https://github.com/state-machines/state_machines-activemodel-observers gem in your 
-    # Gemfile. Because of the way
-    # ActiveModel observers are designed, there is less flexibility around the
-    # specific transitions that can be hooked in.  However, a large number of
-    # hooks *are* supported.  For example, if a transition for a object's
-    # +state+ attribute changes the state from +parked+ to +idling+ via the
-    # +ignite+ event, the following observer methods are supported:
-    # * before/after/after_failure_to-_ignite_from_parked_to_idling
-    # * before/after/after_failure_to-_ignite_from_parked
-    # * before/after/after_failure_to-_ignite_to_idling
-    # * before/after/after_failure_to-_ignite
-    # * before/after/after_failure_to-_transition_state_from_parked_to_idling
-    # * before/after/after_failure_to-_transition_state_from_parked
-    # * before/after/after_failure_to-_transition_state_to_idling
-    # * before/after/after_failure_to-_transition_state
-    # * before/after/after_failure_to-_transition
-    #
-    # The following class shows an example of some of these hooks:
-    #
-    #   class VehicleObserver < ActiveModel::Observer
-    #     # Callback for :ignite event *before* the transition is performed
-    #     def before_ignite(vehicle, transition)
-    #       # log message
-    #     end
-    #
-    #     # Callback for :ignite event *after* the transition has been performed
-    #     def after_ignite(vehicle, transition)
-    #       # put on seatbelt
-    #     end
-    #
-    #     # Generic transition callback *before* the transition is performed
-    #     def after_transition(vehicle, transition)
-    #       Audit.log(vehicle, transition)
-    #     end
-    #
-    #     def after_failure_to_transition(vehicle, transition)
-    #       Audit.error(vehicle, transition)
-    #     end
-    #   end
-    #
-    # More flexible transition callbacks can be defined directly within the
-    # model as described in StateMachine::Machine#before_transition
-    # and StateMachine::Machine#after_transition.
-    #
-    # To define a single observer for multiple state machines:
-    #
-    #   class StateMachineObserver < ActiveModel::Observer
-    #     observe Vehicle, Switch, Project
-    #
-    #     def after_transition(object, transition)
-    #       Audit.log(object, transition)
-    #     end
-    #   end
-    #
     # == Internationalization
     #
     # Any error message that is generated from performing invalid transitions
@@ -308,9 +258,9 @@ module StateMachines
     #     include ActiveModel::Dirty
     #     attr_accessor :state
     #
-    #     state_machine :initial => :parked do
+    #     state_machine initial: :parked do
     #       event :park do
-    #         transition :parked => :parked, ...
+    #         transition parked: :parked, ...
     #       end
     #     end
     #   end
@@ -322,7 +272,7 @@ module StateMachines
     #
     #   class Vehicle
     #     ...
-    #     state_machine :initial => :parked do
+    #     state_machine initial: :parked do
     #       before_transition all => same do |vehicle|
     #         vehicle.state_will_change!
     #
@@ -344,7 +294,7 @@ module StateMachines
     #   module StateMachine::Integrations::MyORM
     #     include ActiveModel
     #
-    #     mattr_accessor(:defaults) { :action => :persist }
+    #     mattr_accessor(:defaults) { { action: :persist } }
     #
     #     def self.matches?(klass)
     #       defined?(::MyORM::Base) && klass <= ::MyORM::Base
@@ -374,22 +324,19 @@ module StateMachines
 
       # Adds a validation error to the given object
       def invalidate(object, attribute, message, values = [])
-        if supports_validations?
-          attribute = self.attribute(attribute)
-          options = values.reduce({}) do |h, (key, value)|
-            h[key] = value
-            h
-          end
+        return unless supports_validations?
 
-          default_options = default_error_message_options(object, attribute, message)
-          object.errors.add(attribute, message, **options, **default_options)
-        end
+        attribute = self.attribute(attribute)
+        options = values.to_h
+
+        default_options = default_error_message_options(object, attribute, message)
+        object.errors.add(attribute, message, **options, **default_options)
       end
 
       # Describes the current validation errors on the given object.  If none
       # are specific, then the default error is interpeted as a "halt".
       def errors_for(object)
-        object.errors.empty? ? 'Transition halted' : object.errors.full_messages * ', '
+        object.errors.empty? ? 'Transition halted' : object.errors.full_messages.join(', ')
       end
 
       # Resets any errors previously added when invalidating the given object
@@ -398,22 +345,32 @@ module StateMachines
       end
 
       # Runs state events around the object's validation process
-      def around_validation(object)
-        object.class.state_machines.transitions(object, action, after: false).perform { yield }
+      def around_validation(object, &)
+        object.class.state_machines.transitions(object, action, after: false).perform(&)
       end
 
       protected
 
       def define_state_initializer
-        define_helper :instance, <<-end_eval, __FILE__, __LINE__ + 1
-          def initialize(params = {})
-            params.transform_keys! do |key|
+        define_helper :instance, <<-END_EVAL, __FILE__, __LINE__ + 1
+          def initialize(params = nil, **kwargs)
+            # Support both positional hash and keyword arguments
+            attrs = params.nil? ? kwargs : params
+          #{'  '}
+            attrs.transform_keys! do |key|
               self.class.attribute_aliases[key.to_s] || key.to_s
             end if self.class.respond_to?(:attribute_aliases)
 
-            self.class.state_machines.initialize_states(self, {}, params) { super }
+            # Call super with the appropriate arguments based on what we received
+            self.class.state_machines.initialize_states(self, {}, attrs) do
+              if params
+                super(params)
+              else
+                super(**kwargs)
+              end
+            end
           end
-        end_eval
+        END_EVAL
       end
 
       # Whether validations are supported in the integration.  Only true if
@@ -431,7 +388,7 @@ module StateMachines
 
       # Gets the terminator to use for callbacks
       def callback_terminator
-        @terminator ||= ->(result) { result == false }
+        @callback_terminator ||= ->(result) { result == false }
       end
 
       # Determines the base scope to use when looking up translations
@@ -461,7 +418,7 @@ module StateMachines
         # Generate all possible translation keys
         translations = ancestors.map { |ancestor| :"#{ancestor.model_name.to_s.underscore}.#{name}.#{group}.#{value}" }
         translations.concat(ancestors.map { |ancestor| :"#{ancestor.model_name.to_s.underscore}.#{group}.#{value}" })
-        translations.concat([:"#{name}.#{group}.#{value}", :"#{group}.#{value}", value.humanize.downcase])
+        translations.push(:"#{name}.#{group}.#{value}", :"#{group}.#{value}", value.humanize.downcase)
         I18n.translate(translations.shift, default: translations, scope: [i18n_scope(klass), :state_machines])
       end
 
@@ -475,10 +432,12 @@ module StateMachines
       def define_state_accessor
         name = self.name
 
+        return unless supports_validations?
+
         owner_class.validates_each(attribute) do |object|
           machine = object.class.state_machine(name)
           machine.invalidate(object, :state, :invalid) unless machine.states.match(object)
-        end if supports_validations?
+        end
       end
 
       # Adds hooks into validation for automatically firing events
@@ -496,7 +455,7 @@ module StateMachines
       # Creates a new callback in the callback chain, always inserting it
       # before the default Observer callbacks that were created after
       # initialization.
-      def add_callback(type, options, &block)
+      def add_callback(type, options, &)
         options[:terminator] = callback_terminator
         super
       end
@@ -504,14 +463,24 @@ module StateMachines
       # Configures new states with the built-in humanize scheme
       def add_states(*)
         super.each do |new_state|
-          new_state.human_name = ->(state, klass) { translate(klass, :state, state.name) }
+          # Only set the translation lambda if human_name is the default auto-generated value
+          # This preserves user-specified human names while still applying translations for defaults
+          default_human_name = new_state.name ? new_state.name.to_s.tr('_', ' ') : 'nil'
+          if new_state.human_name == default_human_name
+            new_state.human_name = ->(state, klass) { translate(klass, :state, state.name) }
+          end
         end
       end
 
       # Configures new event with the built-in humanize scheme
       def add_events(*)
         super.each do |new_event|
-          new_event.human_name = ->(event, klass) { translate(klass, :event, event.name) }
+          # Only set the translation lambda if human_name is the default auto-generated value
+          # This preserves user-specified human names while still applying translations for defaults
+          default_human_name = new_event.name ? new_event.name.to_s.tr('_', ' ') : 'nil'
+          if new_event.human_name == default_human_name
+            new_event.human_name = ->(event, klass) { translate(klass, :event, event.name) }
+          end
         end
       end
     end
