@@ -1,15 +1,18 @@
-require_relative 'test_helper'
+# frozen_string_literal: true
+
+require 'test_helper'
 
 class MachineWithDirtyAttributesAndCustomAttributeTest < BaseTestCase
   def setup
     @model = new_model do
-      include ActiveModel::Dirty
-      model_attribute :status
-      define_attribute_methods [:status]
+      attribute :status, :string
 
       def save
-        super.tap do
+        if valid?
           changes_applied
+          true
+        else
+          false
         end
       end
     end
@@ -24,17 +27,17 @@ class MachineWithDirtyAttributesAndCustomAttributeTest < BaseTestCase
   end
 
   def test_should_include_state_in_changed_attributes
-    assert_equal %w(status), @record.changed
+    assert_equal %w[status], @record.changed
   end
 
   def test_should_track_attribute_change
-    assert_equal %w(parked idling), @record.changes['status']
+    assert_equal %w[parked idling], @record.changes['status']
   end
 
   def test_should_not_reset_changes_on_multiple_transitions
     transition = StateMachines::Transition.new(@record, @machine, :ignite, :idling, :idling)
     transition.perform
 
-    assert_equal %w(parked idling), @record.changes['status']
+    assert_equal %w[parked idling], @record.changes['status']
   end
 end
