@@ -1,9 +1,12 @@
-require_relative 'test_helper'
+# frozen_string_literal: true
+
+require 'test_helper'
 
 class MachineWithInitializedAliasedAttributeTest < BaseTestCase
   def test_should_match_original_attribute_value_with_attribute_methods
     model = new_model do
       include ActiveModel::AttributeMethods
+
       alias_attribute :custom_status, :state
     end
 
@@ -17,7 +20,16 @@ class MachineWithInitializedAliasedAttributeTest < BaseTestCase
   end
 
   def test_should_not_match_original_attribute_value_without_attribute_methods
-    model = new_model do
+    model = new_plain_model do
+      include ActiveModel::Model
+
+      attr_accessor :state
+
+      def self.alias_attribute(new_name, old_name)
+        alias_method new_name, old_name
+        alias_method "#{new_name}=", "#{old_name}="
+      end
+
       alias_attribute :custom_status, :state
     end
 
@@ -30,4 +42,3 @@ class MachineWithInitializedAliasedAttributeTest < BaseTestCase
     refute record.state?(:started)
   end
 end
-
