@@ -1,4 +1,6 @@
-require_relative 'test_helper'
+# frozen_string_literal: true
+
+require 'test_helper'
 
 class MachineWithStateDrivenValidationsTest < BaseTestCase
   def setup
@@ -9,7 +11,7 @@ class MachineWithStateDrivenValidationsTest < BaseTestCase
 
     @machine = StateMachines::Machine.new(@model)
     @machine.state :first_gear, :second_gear do
-      validates_presence_of :seatbelt
+      validates :seatbelt, presence: true
     end
     @machine.other_states :parked
   end
